@@ -421,6 +421,17 @@ document_uri_notify_handler (GeditDocument *document,
 	g_object_notify (G_OBJECT (tab), "name");
 }
 
+static void 
+document_shortname_notify_handler (GeditDocument *document,
+				   GParamSpec    *pspec,
+				   GeditTab      *tab)
+{
+	gedit_debug (DEBUG_TAB);
+	
+	/* Notify the change in the shortname */
+	g_object_notify (G_OBJECT (tab), "name");
+}
+
 static void
 document_modified_changed (GtkTextBuffer *document,
 			   GeditTab      *tab)
@@ -1574,6 +1585,10 @@ gedit_tab_init (GeditTab *tab)
 			  "notify::uri",
 			  G_CALLBACK (document_uri_notify_handler),
 			  tab);
+	g_signal_connect (doc,
+			  "notify::shortname",
+			  G_CALLBACK (document_shortname_notify_handler),
+			  tab);
 	g_signal_connect (doc,
 			  "modified_changed",
 			  G_CALLBACK (document_modified_changed),
@@ -2842,3 +2857,14 @@ gedit_tab_set_auto_save_interval (GeditTab *tab,
 		install_auto_save_timeout (tab);
 	}
 }
+
+void
+gedit_tab_set_info_bar (GeditTab  *tab,
+                        GtkWidget *info_bar)
+{
+	g_return_if_fail (GEDIT_IS_TAB (tab));
+	g_return_if_fail (info_bar == NULL || GTK_IS_WIDGET (info_bar));
+
+	/* FIXME: this can cause problems with the tab state machine */
+	set_message_area (tab, info_bar);
+}
