@@ -405,7 +405,7 @@ class PlaceholderShell(PlaceholderExpand):
                         PlaceholderExpand.remove(self)
 
                 message_dialog(None, gtk.MESSAGE_ERROR, 'Execution of the shell ' \
-                                'command (%s) exceeds the maximum time, ' \
+                                'command (%s) exceeded the maximum time; ' \
                                 'execution aborted.' % self.command)
                 
                 return False
@@ -522,10 +522,21 @@ class PlaceholderEval(PlaceholderExpand):
 
                 return mirrors
 
+        # SIGALRM is not supported on all platforms (e.g. windows). Timeout
+        # with SIGALRM will not be used on those platforms. This will
+        # potentially block gedit if you have a placeholder which gets stuck,
+        # but it's better than not supporting them at all. At some point we
+        # might have proper thread support and we can fix this in a better way
+        def timeout_supported(self):
+                return hasattr(signal, 'SIGALRM')
+
         def timeout_cb(self, signum = 0, frame = 0):
                 raise TimeoutError, "Operation timed out (>2 seconds)"
         
         def install_timeout(self):
+                if not self.timeout_supported():
+                        return
+
                 if self.timeout_id != None:
                         self.remove_timeout()
                 
@@ -533,6 +544,9 @@ class PlaceholderEval(PlaceholderExpand):
                 signal.alarm(2)
                 
         def remove_timeout(self):
+                if not self.timeout_supported():
+                        return
+
                 if self.timeout_id != None:
                         signal.alarm(0)
                         
@@ -577,7 +591,7 @@ class PlaceholderEval(PlaceholderExpand):
                                 self.remove_timeout()
 
                                 message_dialog(None, gtk.MESSAGE_ERROR, \
-                                _('Execution of the python command (%s) exceeds the maximum ' \
+                                _('Execution of the Python command (%s) exceeds the maximum ' \
                                 'time, execution aborted.') % self.command)
                                 
                                 return False
@@ -585,7 +599,7 @@ class PlaceholderEval(PlaceholderExpand):
                                 self.remove_timeout()
                                 
                                 message_dialog(None, gtk.MESSAGE_ERROR, 
-                                _('Execution of the python command (%s) failed: %s') % 
+                                _('Execution of the Python command (%s) failed: %s') % 
                                 (self.command, detail))
 
                                 return False
