@@ -41,7 +41,7 @@
 #include <glib/gi18n.h>
 
 #include "gedit-automatic-spell-checker.h"
-
+#include "gedit-spell-utils.h"
 
 struct _GeditAutomaticSpellChecker {
 	GeditDocument		*doc;
@@ -72,7 +72,7 @@ static void
 check_word (GeditAutomaticSpellChecker *spell, GtkTextIter *start, GtkTextIter *end) 
 {
 	gchar *word;
-	
+
 	word = gtk_text_buffer_get_text (GTK_TEXT_BUFFER (spell->doc), start, end, FALSE);
 
 	/*
@@ -160,11 +160,12 @@ check_range (GeditAutomaticSpellChecker *spell,
 	{
 		gtk_text_iter_forward_word_end(&start);
 		gtk_text_iter_backward_word_start(&start);
-	}	
+	}
 
 	wstart = start;
 	
-	while (gtk_text_iter_compare (&wstart, &end) < 0) 
+	while (gedit_spell_utils_skip_no_spell_check (&wstart, &end) &&
+	       gtk_text_iter_compare (&wstart, &end) < 0) 
 	{
 		gboolean inword; 
 
@@ -415,6 +416,7 @@ build_suggestion_menu (GeditAutomaticSpellChecker *spell, const gchar *word)
 	{		
 		/* no suggestions.  put something in the menu anyway... */
 		GtkWidget *label;
+		/* Translators: Displayed in the "Check Spelling" dialog if there are no suggestions for the current misspelled word */
 		label = gtk_label_new (_("(no suggested words)"));
 		
 		mi = gtk_menu_item_new ();
